@@ -9,6 +9,9 @@ import glob
 import matplotlib.pyplot as plt
 import cv2
 import time
+import sys
+
+#sys.path.insert(0, 'tf2/object_detection')
 
 from object_detection.utils import ops as utils_ops
 from object_detection.utils import label_map_util
